aboutsummaryrefslogtreecommitdiffstats
path: root/Source/SPServerSupport.m
diff options
context:
space:
mode:
Diffstat (limited to 'Source/SPServerSupport.m')
-rw-r--r--Source/SPServerSupport.m8
1 files changed, 4 insertions, 4 deletions
diff --git a/Source/SPServerSupport.m b/Source/SPServerSupport.m
index b32a9dc2..78a2b287 100644
--- a/Source/SPServerSupport.m
+++ b/Source/SPServerSupport.m
@@ -56,7 +56,7 @@
@synthesize supportsSpatialExtensions;
@synthesize supportsShowCharacterSet;
@synthesize supportsShowCollation;
-@synthesize supportsCharacterSetDatabaseVar;
+@synthesize supportsCharacterSetAndCollationVars;
@synthesize supportsPost41CharacterSetHandling;
@synthesize supportsCreateUser;
@synthesize supportsRenameUser;
@@ -142,8 +142,8 @@
// The SHOW COLLATION statement wasn't added until MySQL 4.1.0
supportsShowCollation = [self isEqualToOrGreaterThanMajorVersion:4 minor:1 release:0];
- // The variable 'character_set_database' wasn't added until MySQL 4.1.1
- supportsCharacterSetDatabaseVar = [self isEqualToOrGreaterThanMajorVersion:4 minor:1 release:1];
+ // The variables 'character_set_*' and 'collation_*' weren't added until MySQL 4.1.1
+ supportsCharacterSetAndCollationVars = [self isEqualToOrGreaterThanMajorVersion:4 minor:1 release:1];
// As of MySQL 4.1 encoding support was greatly improved
supportsPost41CharacterSetHandling = [self isEqualToOrGreaterThanMajorVersion:4 minor:1 release:0];
@@ -263,7 +263,7 @@
supportsSpatialExtensions = NO;
supportsShowCharacterSet = NO;
supportsShowCollation = NO;
- supportsCharacterSetDatabaseVar = NO;
+ supportsCharacterSetAndCollationVars = NO;
supportsPost41CharacterSetHandling = NO;
supportsCreateUser = NO;
supportsRenameUser = NO;